/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface FirebaseDataConnectServiceConfig extends cdktf.TerraformMetaArguments {
    /**
    * Optional. Stores small amounts of arbitrary data.
    *
    * **Note**: This field is non-authoritative, and will only manage the annotations present in your configuration.
    * Please refer to the field 'effective_annotations' for all of the annotations present on the resource.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.22.0/docs/resources/firebase_data_connect_service#annotations FirebaseDataConnectService#annotations}
    */
    readonly annotations?: {
        [key: string]: string;
    };
    /**
    * The deletion policy for the database. Setting the field to FORCE allows the
    * Service to be deleted even if a Schema or Connector is present. By default,
    * the Service deletion will only succeed when no Schema or Connectors are
    * present.
    * Possible values: DEFAULT, FORCE
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.22.0/docs/resources/firebase_data_connect_service#deletion_policy FirebaseDataConnectService#deletion_policy}
    */
    readonly deletionPolicy?: string;
    /**
    * Optional. Mutable human-readable name. 63 character limit.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.22.0/docs/resources/firebase_data_connect_service#display_name FirebaseDataConnectService#display_name}
    */
    readonly displayName?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.22.0/docs/resources/firebase_data_connect_service#id FirebaseDataConnectService#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Optional. Labels as key value pairs.
    *
    * **Note**: This field is non-authoritative, and will only manage the labels present in your configuration.
    * Please refer to the field 'effective_labels' for all of the labels present on the resource.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.22.0/docs/resources/firebase_data_connect_service#labels FirebaseDataConnectService#labels}
    */
    readonly labels?: {
        [key: string]: string;
    };
    /**
    * The region in which the service resides, e.g. "us-central1" or "asia-east1".
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.22.0/docs/resources/firebase_data_connect_service#location FirebaseDataConnectService#location}
    */
    readonly location: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.22.0/docs/resources/firebase_data_connect_service#project FirebaseDataConnectService#project}
    */
    readonly project?: string;
    /**
    * Required. The ID to use for the service, which will become the final component of the
    * service's resource name.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.22.0/docs/resources/firebase_data_connect_service#service_id FirebaseDataConnectService#service_id}
    */
    readonly serviceId: string;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.22.0/docs/resources/firebase_data_connect_service#timeouts FirebaseDataConnectService#timeouts}
    */
    readonly timeouts?: FirebaseDataConnectServiceTimeouts;
}
export interface FirebaseDataConnectServiceTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.22.0/docs/resources/firebase_data_connect_service#create FirebaseDataConnectService#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.22.0/docs/resources/firebase_data_connect_service#delete FirebaseDataConnectService#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.22.0/docs/resources/firebase_data_connect_service#update FirebaseDataConnectService#update}
    */
    readonly update?: string;
}
export declare function firebaseDataConnectServiceTimeoutsToTerraform(struct?: FirebaseDataConnectServiceTimeouts | cdktf.IResolvable): any;
export declare function firebaseDataConnectServiceTimeoutsToHclTerraform(struct?: FirebaseDataConnectServiceTimeouts | cdktf.IResolvable): any;
export declare class FirebaseDataConnectServiceTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): FirebaseDataConnectServiceTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: FirebaseDataConnectServiceTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google/6.22.0/docs/resources/firebase_data_connect_service google_firebase_data_connect_service}
*/
export declare class FirebaseDataConnectService extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_firebase_data_connect_service";
    /**
    * Generates CDKTF code for importing a FirebaseDataConnectService resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the FirebaseDataConnectService to import
    * @param importFromId The id of the existing FirebaseDataConnectService that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google/6.22.0/docs/resources/firebase_data_connect_service#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the FirebaseDataConnectService to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google/6.22.0/docs/resources/firebase_data_connect_service google_firebase_data_connect_service} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options FirebaseDataConnectServiceConfig
    */
    constructor(scope: Construct, id: string, config: FirebaseDataConnectServiceConfig);
    private _annotations?;
    get annotations(): {
        [key: string]: string;
    };
    set annotations(value: {
        [key: string]: string;
    });
    resetAnnotations(): void;
    get annotationsInput(): {
        [key: string]: string;
    } | undefined;
    get createTime(): string;
    private _deletionPolicy?;
    get deletionPolicy(): string;
    set deletionPolicy(value: string);
    resetDeletionPolicy(): void;
    get deletionPolicyInput(): string | undefined;
    private _displayName?;
    get displayName(): string;
    set displayName(value: string);
    resetDisplayName(): void;
    get displayNameInput(): string | undefined;
    private _effectiveAnnotations;
    get effectiveAnnotations(): cdktf.StringMap;
    private _effectiveLabels;
    get effectiveLabels(): cdktf.StringMap;
    get etag(): string;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _labels?;
    get labels(): {
        [key: string]: string;
    };
    set labels(value: {
        [key: string]: string;
    });
    resetLabels(): void;
    get labelsInput(): {
        [key: string]: string;
    } | undefined;
    private _location?;
    get location(): string;
    set location(value: string);
    get locationInput(): string | undefined;
    get name(): string;
    private _project?;
    get project(): string;
    set project(value: string);
    resetProject(): void;
    get projectInput(): string | undefined;
    get reconciling(): cdktf.IResolvable;
    private _serviceId?;
    get serviceId(): string;
    set serviceId(value: string);
    get serviceIdInput(): string | undefined;
    private _terraformLabels;
    get terraformLabels(): cdktf.StringMap;
    get uid(): string;
    get updateTime(): string;
    private _timeouts;
    get timeouts(): FirebaseDataConnectServiceTimeoutsOutputReference;
    putTimeouts(value: FirebaseDataConnectServiceTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | FirebaseDataConnectServiceTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
