/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface SpannerInstancePartitionConfig extends cdktf.TerraformMetaArguments {
    /**
    * The name of the instance partition's configuration (similar to a region) which
    * defines the geographic placement and replication of data in this instance partition.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.22.0/docs/resources/spanner_instance_partition#config SpannerInstancePartition#config}
    */
    readonly config: string;
    /**
    * The descriptive name for this instance partition as it appears in UIs.
    * Must be unique per project and between 4 and 30 characters in length.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.22.0/docs/resources/spanner_instance_partition#display_name SpannerInstancePartition#display_name}
    */
    readonly displayName: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.22.0/docs/resources/spanner_instance_partition#id SpannerInstancePartition#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * The instance to create the instance partition in.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.22.0/docs/resources/spanner_instance_partition#instance SpannerInstancePartition#instance}
    */
    readonly instance: string;
    /**
    * A unique identifier for the instance partition, which cannot be changed after
    * the instance partition is created. The name must be between 2 and 64 characters
    * and match the regular expression [a-z][a-z0-9\\-]{0,61}[a-z0-9].
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.22.0/docs/resources/spanner_instance_partition#name SpannerInstancePartition#name}
    */
    readonly name: string;
    /**
    * The number of nodes allocated to this instance partition. One node equals
    * 1000 processing units. Exactly one of either node_count or processing_units
    * must be present.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.22.0/docs/resources/spanner_instance_partition#node_count SpannerInstancePartition#node_count}
    */
    readonly nodeCount?: number;
    /**
    * The number of processing units allocated to this instance partition.
    * Exactly one of either node_count or processing_units must be present.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.22.0/docs/resources/spanner_instance_partition#processing_units SpannerInstancePartition#processing_units}
    */
    readonly processingUnits?: number;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.22.0/docs/resources/spanner_instance_partition#project SpannerInstancePartition#project}
    */
    readonly project?: string;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.22.0/docs/resources/spanner_instance_partition#timeouts SpannerInstancePartition#timeouts}
    */
    readonly timeouts?: SpannerInstancePartitionTimeouts;
}
export interface SpannerInstancePartitionTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.22.0/docs/resources/spanner_instance_partition#create SpannerInstancePartition#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.22.0/docs/resources/spanner_instance_partition#delete SpannerInstancePartition#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.22.0/docs/resources/spanner_instance_partition#update SpannerInstancePartition#update}
    */
    readonly update?: string;
}
export declare function spannerInstancePartitionTimeoutsToTerraform(struct?: SpannerInstancePartitionTimeouts | cdktf.IResolvable): any;
export declare function spannerInstancePartitionTimeoutsToHclTerraform(struct?: SpannerInstancePartitionTimeouts | cdktf.IResolvable): any;
export declare class SpannerInstancePartitionTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): SpannerInstancePartitionTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: SpannerInstancePartitionTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google/6.22.0/docs/resources/spanner_instance_partition google_spanner_instance_partition}
*/
export declare class SpannerInstancePartition extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_spanner_instance_partition";
    /**
    * Generates CDKTF code for importing a SpannerInstancePartition resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the SpannerInstancePartition to import
    * @param importFromId The id of the existing SpannerInstancePartition that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google/6.22.0/docs/resources/spanner_instance_partition#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the SpannerInstancePartition to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google/6.22.0/docs/resources/spanner_instance_partition google_spanner_instance_partition} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options SpannerInstancePartitionConfig
    */
    constructor(scope: Construct, id: string, config: SpannerInstancePartitionConfig);
    private _config?;
    get config(): string;
    set config(value: string);
    get configInput(): string | undefined;
    private _displayName?;
    get displayName(): string;
    set displayName(value: string);
    get displayNameInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _instance?;
    get instance(): string;
    set instance(value: string);
    get instanceInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _nodeCount?;
    get nodeCount(): number;
    set nodeCount(value: number);
    resetNodeCount(): void;
    get nodeCountInput(): number | undefined;
    private _processingUnits?;
    get processingUnits(): number;
    set processingUnits(value: number);
    resetProcessingUnits(): void;
    get processingUnitsInput(): number | undefined;
    private _project?;
    get project(): string;
    set project(value: string);
    resetProject(): void;
    get projectInput(): string | undefined;
    get state(): string;
    private _timeouts;
    get timeouts(): SpannerInstancePartitionTimeoutsOutputReference;
    putTimeouts(value: SpannerInstancePartitionTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | SpannerInstancePartitionTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
